@@ -13,8 +13,9 @@ from .cwt import (
 from .encrypted_cose_key import EncryptedCOSEKey
 from .exceptions import CWTError, DecodeError, EncodeError, VerifyError
 from .recipient import Recipient
+from .signer import Signer
 
-__version__ = "0.8.1"
+__version__ = "0.9.0"
 __title__ = "cwt"
 __description__ = "A Python implementation of CWT/COSE"
 __url__ = "https://python-cwt.readthedocs.io"
@@ -37,6 +38,7 @@ __all__ = [
     "EncryptedCOSEKey",
     "Claims",
     "Recipient",
+    "Signer",
     "CWTError",
     "EncodeError",
     "DecodeError",
