@@ -40,7 +40,10 @@ extensions = [
 ]
 
 nitpick_ignore = [
-    ("py:class", "cwt.cose_key.COSEKey"),
+    ("py:class", "T"),
+    ("py:class", "cwt.COSEKeyInterface"),
+    ("py:class", "cwt.RecipientInterface"),
+    ("py:class", "cwt.claims.T"),
     ("py:class", "cwt.cbor_processor.CBORProcessor"),
     ("py:class", "_cbor2.CBORTag"),
     ("py:class", "cwt.exceptions.CWTError"),
